@@ -5,12 +5,12 @@ def expand_multi_table_selects(expression):
     for from_ in expression.find_all(exp.From):
         parent = from_.parent
 
-        for query in from_.args["expressions"][1:]:
+        for query in from_.expressions[1:]:
             parent.join(
                 query,
                 join_type="CROSS",
                 copy=False,
             )
-            from_.args["expressions"].remove(query)
+            from_.expressions.remove(query)
 
     return expression
